﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;
using SampleProject.Web.Resources;
using SampleProject.Web.Repositories;
using SampleProject.DAL.HelperClasses;
using SampleProject.DAL.EntityClasses;
using MonoSoftware.Web.DataManager;
using MonoSoftware.MonoX;
using MonoSoftware.MonoX.Utilities;
using MonoSoftware.Core;
using MonoSoftware.MonoX.PrivacyManager;
using System.Text;
using MonoSoftware.MonoX.DAL.EntityClasses;
using MonoSoftware.MonoX.MonoXDataManager;

namespace SampleProject.Web.ModuleGallery
{
    public partial class EditProfile : MonoSoftware.MonoX.ModuleGallery.EditProfile
    {
        #region Fields
        /// <summary>
        /// Data manager used to transfer and convert data to and from controls
        /// </summary>
        DataManager dataManager = new DataManagerHideEmptyFields();
        #endregion

        #region Control events
        protected override void OnInit(EventArgs e)
        {
            // Normally we would uses resource files
            lblSampleField.Text = "My Dogs Name";

            // Add databindings
            dataManager.DataBindings.Add(SampleField, prevSampleField, ExtendedUserProfileFields.Dog.Name, rowSampleData);
            dataManager.IsPreviewMode = IsPreviewMode;
            privacyManagerCustom.CurrentDataManager = dataManager;
            privacyManagerCustom.ObjectTypeFullName = typeof(ExtendedUserProfileEntity).FullName;
            privacyManagerCustom.PrivacyButtonImageUrl = Paths.App_Themes.img.privacy_icon_png;
            privacyManagerCustom.PrivacyButtonHoverImageUrl = Paths.App_Themes.img.privacy_icon_hover_png;
            privacyManagerCustom.Visible = ShowPrivacyEditor && !IsPreviewMode;
            privacyManagerCustom.DataBind();
            // Get the user whose profile we're viewing to set the privacy manager UserId
            if (UrlParams.UserProfile.UserName.HasValue)
            {
                var user = System.Web.Security.Membership.GetUser(UrlParams.UserProfile.UserName.Value);
                if (user != null)
                    privacyManagerCustom.UserId = new Guid(user.ProviderUserKey.ToString());
            }
            this.Saved += new UserProfileEventHandler(EditProfile_Saved);
            base.DataManager.ToControlsTransfered += new DataManagerTransferEventHandler(DataManager_ToControlsTransfered);
            this.Page.LoadComplete += new EventHandler(Page_LoadComplete);
            base.OnInit(e);
        }

        void Page_LoadComplete(object sender, EventArgs e)
        {
            dataManager.InitControlVisibility();
        }
        #endregion

        #region Methods
        void DataManager_ToControlsTransfered(object dataSource, DataManagerBindingCollection dataBindings)
        {
            dataManager.IsPreviewMode = IsPreviewMode;
            dataManager.AutoValidationGroup = ValidationGroup;
            if (privacyManager.UserId != Guid.Empty)
            {
                var extendedUserProfile = UserRepository.GetInstance().GetExtendedUserProfileOrDefault(privacyManager.UserId);
                if (extendedUserProfile != null)
                {
                    dataManager.TransferDataToControls(extendedUserProfile);
                    dataManager.InitControlVisibility();
                }
            }
        }

        /// <summary>
        /// Triggered when the users profile is saved
        /// </summary>
        /// <param name="userId">UserId</param>
        void EditProfile_Saved(Guid userId)
        {
            if (userId != Guid.Empty)
            {
                var rep = UserRepository.GetInstance();
                var extendedUserProfile = rep.GetExtendedUserProfileOrDefault(userId);
                if (extendedUserProfile != null)
                {
                    dataManager.TransferDataFromControls(extendedUserProfile);
                    rep.SaveEntity(extendedUserProfile);
                }
            }
        }

        #endregion
    }
}