﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using MonoSoftware.LLBLGen;
using SD.LLBLGen.Pro.ORMSupportClasses;
using MonoSoftware.MonoX;
using SCC.Data.DatabaseSpecific;

namespace SCC.Web.Repositories
{
    public class BaseRepository : RepositoryExtender, IDisposable
    {
        #region Constructor
        /// <summary>
        /// Constructor.
        /// </summary>
        protected BaseRepository()
            : base()
        {
        }
        /// <summary>
        /// Returns an instance of the repository class, wraps the constructor to allow for encapsulated instatiation, so the logic in he constructor can be changed without changing the client code.
        /// Reference: http://www.netobjectives.com/ezines/ez0405NetObj_PerspectivesOfUseVsCreationInOODesign.pdf
        /// </summary>
        /// <returns>Instance of the base repository.</returns>
        public static BaseRepository GetInstance()
        {
            return new BaseRepository();
        }
        #endregion

        #region Methods
        /// <summary>
        /// Creates the LLBLGen IDataAccessAdapter.
        /// </summary>
        /// <returns>LLBLGen IDataAccessAdapter</returns>
        public override IDataAccessAdapter GetAdapter()
        {
            return CreateAdapter();
        }

        /// Used to create database-independant LLBLGen DataAdapter.
        /// </summary>
        /// <param name="connectionString">Connection string to use</param>
        /// <returns>IDataAccessAdapter for MonoX DAL</returns>
        public virtual IDataAccessAdapter GetAdapter(string connectionString)
        {
            return CreateAdapter(connectionString);
        }

        /// <summary>
        /// Used to create database-independant LLBLGen DataAdapter.
        /// </summary>
        /// <returns>IDataAccessAdapter for MonoX DAL</returns>
        private IDataAccessAdapter CreateAdapter()
        {
            IDataAccessAdapter toReturn = null;
            try
            {
                toReturn = CreateAdapter(ApplicationSettings.LocalSqlServer);
            }
            catch { }

            return toReturn;
        }

        /// <summary>
        /// Used to create database-independant LLBLGen DataAdapter.
        /// </summary>
        /// <param name="connectionString">Connection string to use</param>
        /// <returns>IDataAccessAdapter for MonoX DAL</returns>
        private IDataAccessAdapter CreateAdapter(string connectionString)
        {
            return new DataAccessAdapter(connectionString, false, SD.LLBLGen.Pro.ORMSupportClasses.CatalogNameUsage.Clear, null);//, SD.LLBLGen.Pro.ORMSupportClasses.CatalogNameUsage.ForceName, MonoSoftware.Knorg.Properties.Settings.Default.SqlCatalogNameToUse);
        }
        #endregion

        #region IDisposable Members

        public void Dispose()
        {
        }

        #endregion
    }
}